@@ -1,5 +1,5 @@
-package Directory::Scratch; # git description: v0.15-1-g5e2e598
-$Directory::Scratch::VERSION = '0.16';
+package Directory::Scratch; # git description: v0.16-5-g2428a09
+$Directory::Scratch::VERSION = '0.17';
 # see POD after __END__.
 
 use warnings;
@@ -242,7 +242,7 @@ sub write {
     }
     else { # (cut'n'paste)++
 	local $, = $, || "\n";
-	path($path->stringify)->spew(@_, '') 
+	path($path->stringify)->append({ truncate => 1 }, @_, '')
 	  or croak "Error writing file: $!";
     }
     return 1;
@@ -405,9 +405,10 @@ sub randfile {
     
     my ($fh, $name) = $self->tempfile;
     croak "Could not open $name: $!" if !$fh;
+    close $fh;
     
     my $rand = String::Random->new();
-    path($name)->spew($rand->randregex(".{$min,$max}"));    
+    path($name)->append({ truncate => 1 }, $rand->randregex(".{$min,$max}"));
     
     return file($name);
 }
@@ -425,11 +426,11 @@ __END__
 
 =head1 NAME
 
-Directory::Scratch - (DEPRECATED) Easy-to-use self-cleaning scratch space.
+Directory::Scratch - (DEPRECATED) Easy-to-use self-cleaning scratch space
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 DEPRECATION NOTICE
 
